module License.NPL exposing
  ( Module
  , info
  )

import License exposing
  ( DownloadType
  , LicenseInfo
  , ModuleInfo
  )
import Html exposing (text)

info : LicenseInfo Module
info =
  { availableModules = availableModules
  , templates = getTemplate
  , moduleInfo = moduleInfo
  }

type Module
  = WorkerOwnership
  | Attribution

availableModules : List Module
availableModules =
  [ WorkerOwnership
  , Attribution
  ]

moduleInfo : Module -> ModuleInfo
moduleInfo mod = case mod of
  WorkerOwnership ->
    { name = "Worker Ownership"
    , desc =
      [ text
        """
        Restrict comercial use of your software to worker-owned businesses and
        collectives.  Rights are still granted for non-comercial use by traditional
        businesses and individuals.
        """
      ]
    , index = 0
    }
  Attribution ->
    { name = "Attribution"
    , desc =
      [ text
        """
        Require that anyone who uses the software list your name/psuedonym, the original
        title of the software, the website/repository of the project, and credit in the
        case of attribution.  You can always ask distributors to take down the attribution
        as well
        """
      ]
    , index = 1
    }

getTemplate : DownloadType -> List (Maybe Module, String)
getTemplate _ =
  [ (Nothing, "NPL filler text")
  , (Just WorkerOwnership, "+ Cooperative")
  , (Just Attribution, "+ Attribution")
  ]
